import { IconButton, Span } from '@components/ui';
import DeleteIcon from '@public/images/svg/delete.svg';
import PlusIcon from '@public/images/svg/plus.svg';
import React, { useState } from 'react';

import { FlorisTableRow } from './components';
import styles from './styles.module.scss';
import { FlorisTableProps, FlorisTableTurbine } from './types';

export function FlorisTable({ value = [], onChange }: FlorisTableProps) {
  const [selectedRows, setSelectedRows] = useState<Record<string, boolean>>({});

  const handleDeleteButtonClick = () => {
    onChange?.(value.filter((_, i) => !selectedRows[i]));
    setSelectedRows({});
  };

  const handlePlusButtonClick = () => {
    onChange?.([...value, { x: '', y: '', angle: '' }]);
  };

  const handleRowChange = (index: number, turbine: FlorisTableTurbine) => {
    onChange?.(value.with(index, turbine));
  };

  const handleRowSelect = (index: number) => {
    const checked = !selectedRows[index];
    setSelectedRows({ ...selectedRows, [index]: checked });
  };

  return (
    <div className={styles.table}>
      <header className={styles.header}>
        <Span className={styles.span} />
        <Span className={styles.span}>x</Span>
        <Span className={styles.span}>y</Span>
        <Span className={styles.span}>angle</Span>
      </header>
      {value.map((v, i) => (
        <FlorisTableRow
          key={i}
          value={v}
          onChange={(turbine) => handleRowChange(i, turbine)}
          onSelect={() => handleRowSelect(i)}
          selected={selectedRows[i] ?? false}
        />
      ))}
      <footer className={styles.footer}>
        <IconButton onClick={handleDeleteButtonClick}>
          <DeleteIcon />
        </IconButton>
        <IconButton onClick={handlePlusButtonClick}>
          <PlusIcon />
        </IconButton>
      </footer>
    </div>
  );
}
