import { Heading, Span } from '@components/ui';
import clsx from 'clsx';
import React from 'react';

import styles from './style.module.scss';
import { PowerSectionProps } from './types';

export function PowerSection({ power, dateFrom }: PowerSectionProps) {
  const gridTemplateColumns = `repeat(${power[0].length + 1}, 1fr)`;
  const date = new Date(dateFrom);

  return (
    <section className={styles.section}>
      <Heading tag="h3">Power, watt per hour</Heading>
      <div>
        <div className={styles.row} style={{ gridTemplateColumns }}>
          <Span className={clsx(styles.cell, styles.mainCell)}></Span>
          {power[0].map((_, i) => (
            <Span className={clsx(styles.cell, styles.mainCell)} key={i}>
              {i + 1}
            </Span>
          ))}
        </div>
        {power.map((row, r) => {
          const day = String(date.getDate()).padStart(2, '0');
          const month = String(date.getMonth() + 1).padStart(2, '0');
          const year = date.getFullYear();
          const dateStr = `${day}.${month}.${year}`;
          date.setDate(date.getDate() + 1);
          return (
            <div className={styles.row} style={{ gridTemplateColumns }} key={r}>
              <Span className={clsx(styles.cell, styles.mainCell)}>
                {dateStr}
              </Span>
              {row.map((value, c) => (
                <Span className={styles.cell} color="t300" key={c}>
                  {value}
                </Span>
              ))}
            </div>
          );
        })}
      </div>
    </section>
  );
}
